Detect outliers for small-plot trial analysis
outlier_summary.RdProvides a summary of the outliers present in the asreml model. Gives context to the outliers by showing the responses for the same factor combinations as the outliers
Value
NULL
Prints:
The number of outliers.
A table of the outliers, if any.
A table of relevant context to some factor combinations, if there are outliers.
Examples
if (FALSE) { # requireNamespace("asreml", quietly = TRUE)
library(asreml)
model <- asreml(
fixed = weight ~ littersize + Dose + Sex + Dose:Sex,
random = ~ idv(Dam),
residual = ~units,
data = rats
)
outlier_summary(model)
}